@@ -56,8 +56,9 @@ def AddShortCut(File, Link="link.lnk", Path: str = ".//"):
     """
     给文件添加一个快捷键到指定位置
 
-    File指定文件，Link指定快捷键名称，Path指定保存的位置。
-
+    :param File: 指定文件，
+    :param Link: 指定快捷键名称。
+    :param Path: 指定保存的位置。
     """
 
     from win32com.client import Dispatch
@@ -85,6 +86,11 @@ def AutoStart(File: str, Name: str = "Application"):
 
 
 def Package(File, Ofter="-w", StartMenu: bool = True):
+
+    """
+    用于打包Python文件。
+    """
+
     try:
         import pyinstaller
     except:
@@ -141,7 +147,7 @@ def Install(Library, Basic: bool = True, Preview: bool = False, Pypi="https://py
 
 def Install_ALL(Basic=True, Preview: bool = False, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     import sys
-    Install("tkinter-tooltip", Basic=Basic, Pypi=Pypi, Preview=Preview)
+    Install("win10toast", Basic=Basic, Pypi=Pypi, Preview=Preview)
     Install("pywin32", Basic=Basic, Pypi=Pypi, Preview=Preview)
     if sys.platform == "win32" and sys.getwindowsversion().build >= 22000:
         Install("win32mica", Basic=Basic, Pypi=Pypi, Preview=Preview)
@@ -250,7 +256,10 @@ def sendmessage(window: tk.Tk, command, ofter, num):
 
 def window_move(widget: tk.Widget, window: tk.Tk):
     """
-    用于拖动窗口，widget为使窗口移动的组件，window为被移动的窗口
+    用于拖动窗口。
+
+    :param widget: 为使窗口移动的组件
+    :param window: 为被移动的窗口
     """
     def move(evt):
         ReleaseCapture()
@@ -294,7 +303,10 @@ def window_acrylic(window: tk.Tk, dark=False, acrylic: bool = False, hexColor: b
 
 def window_long(window: tk.Tk, long):
     """
-    用于内部工作的组件，设置窗口，window为设置的组件，long为设置的参数
+    用于内部工作的组件，设置窗口，
+
+    :param window: 为设置的组件
+    :param long: 为设置的参数
     """
     def long():
         hwnd = GetParent(window.winfo_id())
@@ -305,7 +317,10 @@ def window_long(window: tk.Tk, long):
 
 def window_ex_long(window: tk.Tk, long):
     """
-    用于内部工作的组件，设置扩展窗口，window为设置的组件，long为设置的参数
+    用于内部工作的组件，设置扩展窗口。
+
+    :param window: 为设置的组件，
+    :param long: 为设置的参数
     """
     hwnd = GetParent(window.winfo_id())
     res = SetWindowLong(hwnd, GWL_EXSTYLE, GetWindowLong(hwnd, GWL_EXSTYLE) & ~long)
@@ -313,7 +328,9 @@ def window_ex_long(window: tk.Tk, long):
 
 def window_tiled(window: tk.Tk):
     """
-    设置窗口标题，window为要被设置的窗口
+    设置窗口标题
+
+    :param window: 为设置的组件，
     """
     hwnd = GetParent(window.winfo_id())
     res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_TILED)
@@ -321,7 +338,9 @@ def window_tiled(window: tk.Tk):
 
 def window_mica_light(window: tk.Tk):
     """
-    设置窗口背景材质为云母，并将主题设为明亮，window为要被设置的窗口
+    设置窗口背景材质为云母，并将主题设为明亮
+
+    :param window: 为设置的组件，
     """
     try:
         import win32mica as mc
@@ -333,7 +352,9 @@ def window_mica_light(window: tk.Tk):
 
 def window_mica_dark(window: tk.Tk):
     """
-    设置窗口背景材质为云母，并将主题设为暗黑，window为要被设置的窗口
+    设置窗口背景材质为云母，并将主题设为暗黑
+
+    :param window: 为设置的组件，
     """
     try:
         import win32mica as mc
@@ -345,7 +366,11 @@ def window_mica_dark(window: tk.Tk):
 
 def window_pos_bottom_right(window: tk.Tk, padx: int = 15, pady: int = 15):
     """
-    将窗口放在右下位置，window为要被设置的窗口，padx表示X间距，pady表示Y间距
+    将窗口放在右下位置，
+
+    :param window: 为设置的组件。
+    :param padx: 表示X间距
+    :param pady: 表示Y间距
     """
     window.after(1, lambda: window.geometry(
         f"+{window.winfo_screenwidth() - window.winfo_width() - padx - 10}+"
@@ -354,7 +379,11 @@ def window_pos_bottom_right(window: tk.Tk, padx: int = 15, pady: int = 15):
 
 def window_pos_bottom_left(window: tk.Tk, padx: int = 15, pady: int = 15):
     """
-    将窗口放在左下位置，window为要被设置的窗口，padx表示X间距，pady表示Y间距
+    将窗口放在左下位置。
+
+    :param window: 为设置的组件。
+    :param padx: 表示X间距
+    :param pady: 表示Y间距
     """
     window.after(1, lambda: window.geometry(
         f"+{padx}+{window.winfo_screenheight() - taskbar_height - window.winfo_height() - pady - 35}"))
@@ -362,7 +391,11 @@ def window_pos_bottom_left(window: tk.Tk, padx: int = 15, pady: int = 15):
 
 def window_pos_top_right(window: tk.Tk, padx: int = 15, pady: int = 15):
     """
-    将窗口放在右上位置，window为要被设置的窗口，padx表示X间距，pady表示Y间距
+    将窗口放在右上位置。
+
+    :param window: 为设置的组件。
+    :param padx: 表示X间距
+    :param pady: 表示Y间距
     """
     window.after(1, lambda: window.geometry(
         f"+{window.winfo_screenwidth() - window.winfo_width() - padx - 10}+{pady}"))
@@ -370,7 +403,11 @@ def window_pos_top_right(window: tk.Tk, padx: int = 15, pady: int = 15):
 
 def window_pos_top_left(window: tk.Tk, padx: int = 15, pady: int = 15):
     """
-    将窗口放在左上位置，window为要被设置的窗口，padx表示X间距，pady表示Y间距
+    将窗口放在左上位置
+
+    :param window: 为设置的组件。
+    :param padx: 表示X间距
+    :param pady: 表示Y间距
     """
     window.after(1, lambda: window.geometry(
         f"+{padx}+{pady}"))
@@ -378,7 +415,9 @@ def window_pos_top_left(window: tk.Tk, padx: int = 15, pady: int = 15):
 
 def window_sizebox(window: tk.Tk):
     """
-    设置窗口是否有调整大小的边框，window为要被设置的窗口
+    设置窗口是否有调整大小的边框
+
+    :param window: 为设置的组件。
     """
     def sizebox():
         hwnd = GetParent(window.winfo_id())
@@ -389,7 +428,9 @@ def window_sizebox(window: tk.Tk):
 
 def window_maxbox(window: tk.Tk):
     """
-    设置窗口是否有最大化按钮，window为要被设置的窗口
+    设置窗口是否有最大化按钮
+
+    :param window: 为设置的组件。
     """
     def max():
         hwnd = GetParent(window.winfo_id())
@@ -400,7 +441,9 @@ def window_maxbox(window: tk.Tk):
 
 def window_minbox(window: tk.Tk):
     """
-    设置窗口是否有最小化按钮，window为要被设置的窗口
+    设置窗口是否有最小化按钮
+
+    :param window: 为设置的组件。
     """
     def min():
         hwnd = GetParent(window.winfo_id())
@@ -411,7 +454,9 @@ def window_minbox(window: tk.Tk):
 
 def window_grayed_closebox(window: tk.Tk):
     """
-    禁用关闭按钮，window为要被设置的窗口
+    禁用关闭按钮
+
+    :param window: 为设置的组件。
     """
     def close():
         hwnd = GetParent(window.winfo_id())
@@ -422,7 +467,9 @@ def window_grayed_closebox(window: tk.Tk):
 
 def window_enabled_closebox(window: tk.Tk):
     """
-    启用关闭按钮，window为要被设置的窗口
+    启用关闭按钮
+
+    :param window: 为设置的组件。
     """
     def close():
         hwnd = GetParent(window.winfo_id())
@@ -433,7 +480,9 @@ def window_enabled_closebox(window: tk.Tk):
 
 def window_popup(window: tk.Tk):
     """
-    使窗口变成弹出状态，window为要被设置的窗口
+    使窗口变成弹出状态
+
+    :param window: 为设置的组件。
     """
     def popup():
         hwnd = GetParent(window.winfo_id())
@@ -444,7 +493,9 @@ def window_popup(window: tk.Tk):
 
 def window_custom_taskbar(window: tk.Tk):
     """
-    自定义窗口，出现在任务栏中，window为要被设置的窗口
+    自定义窗口，出现在任务栏中
+
+    :param window: 为设置的组件。
     """
     def over():
         hwnd = GetParent(window.winfo_id())
@@ -457,7 +508,9 @@ def window_custom_taskbar(window: tk.Tk):
 
 def window_custom_border_taskbar(window: tk.Tk):
     """
-    自定义窗口，保留边框，出现在任务栏中，window为要被设置的窗口
+    自定义窗口，保留边框，出现在任务栏中
+
+    :param window: 为设置的组件。
     """
     def custom():
         hwnd = GetParent(window.winfo_id())
@@ -470,6 +523,8 @@ def window_custom_border_taskbar(window: tk.Tk):
 def window_add_taskbar(window: tk.Tk):
     """
     将窗口放入任务栏
+
+    :param window: 为设置的组件。
     """
     hwnd = GetParent(window.winfo_id())
     res = SetWindowLong(hwnd, GWL_EXSTYLE, GetWindowLong(hwnd, GWL_EXSTYLE) & ~WS_EX_TOOLWINDOW | WS_EX_APPWINDOW)
@@ -480,7 +535,9 @@ def window_add_taskbar(window: tk.Tk):
 
 def window_border(window: tk.Tk):
     """
-    使窗口保留边框，去除标题栏，window为要被设置的窗口
+    使窗口保留边框，去除标题栏
+
+    :param window: 为设置的组件。
     """
     def border():
         hWnd = GetParent(window.winfo_id())
@@ -493,7 +550,11 @@ def window_border(window: tk.Tk):
 
 def window_embed(window: tk.Tk, toplevel: tk.Toplevel, iswindow: bool = True):
     """
-    将窗口嵌入到容器里，window设置为被嵌入的容器，toplevel设置为嵌入的窗口，iswindow确认容器是否使窗口
+    将窗口嵌入到容器里，
+
+    :param window: 设置为被嵌入的容器
+    :param toplevel: 设置为嵌入的窗口
+    :param iswindow: 确认容器是否使窗口
     """
     def embed():
         SetParent(GetParent(toplevel.winfo_id()), window.winfo_id())
@@ -508,7 +569,9 @@ def window_embed(window: tk.Tk, toplevel: tk.Toplevel, iswindow: bool = True):
 
 def window_centre(window: tk.Tk):
     """
-    将窗口居中，window为要被设置的窗口
+    将窗口居中
+
+    :param window: 为设置的组件。
     """
     x = window.winfo_screenwidth() / 2 - window.winfo_width() / 2
     y = window.winfo_screenheight() / 2 - window.winfo_height() / 2
@@ -517,7 +580,9 @@ def window_centre(window: tk.Tk):
 
 def window_custom(window: tk.Tk):
     """
-    去除窗口标题栏，window为要被设置的窗口
+    去除窗口标题栏
+
+    :param window: 为设置的组件。
     """
     hwnd = GetParent(window.winfo_id())
     res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_CAPTION)
@@ -589,12 +654,11 @@ class DevDrag(object):
     def __init__(self, widget: tk.Widget, dragwidget: tk.Widget, iswindow: bool = False, x: bool = True, y: bool = True,
                  click_func=None, noclick_func=None, move_func=None):
         """
-        这个组件能够拖动组件移动，实现更高级的功能。widget设为拖动命令的组件，你拖动这个组件，拖动的组件会移动。dragwidget设为被拖动的组件。
-        iswindow是声明你要拖动的组件是窗口还是组件，是窗口填True，是组件填False。
+        这个组件能够拖动组件移动，实现更高级的功能。
 
-        :param widget:
-        :param dragwidget:
-        :param iswindow:
+        :param widget: 设为拖动命令的组件，你拖动这个组件，拖动的组件会移动。
+        :param dragwidget: 设为被拖动的组件。
+        :param iswindow: 是声明你要拖动的组件是窗口还是组件，是窗口填True，是组件填False。
         """
         self.widget = widget
         self.dragwidget = dragwidget
@@ -703,7 +767,12 @@ class DevFoldFrame(tk.Frame):
 class DevHeaderBar(tk.Frame):
     def __init__(self, master: tk.Tk, border: bool = True, background="#ffffff", double_max: bool = True):
         """
-        标题栏组件，能够自定义窗口标题栏。master为被设置窗口，border设置是否保留边框，background设置标题栏背景，double_max设置是否可以通过双击按钮最大化。
+        标题栏组件，能够自定义窗口标题栏。
+
+        :param master: 为被设置窗口。
+        :param border: 设置是否保留边框
+        :param background: 设置标题栏背景
+        :param double_max: 设置是否可以通过双击按钮最大化。
         """
         super(DevHeaderBar, self).__init__(master=master, background=background, height=35)
         self.master = master
@@ -722,8 +791,14 @@ class DevHeaderBar(tk.Frame):
                          background="#ffffff", foreground="#000000",
                          activebackground="#c42b1c", activeforeground="#ffffff"):
         """
-        为标题栏添加关闭按钮，text为关闭按钮的文本，font为关闭按钮的字体，background为关闭按钮的背景颜色，foreground为关闭按钮的前景颜色，
-        activebackground为关闭按钮触发时的背景颜色，activeforeground为关闭按钮触发时的前景颜色
+        为标题栏添加关闭按钮。
+
+        :param text: 为关闭按钮的文本
+        :param font: 为关闭按钮的字体
+        :param background: 为关闭按钮的背景颜色
+        :param foreground: 为关闭按钮的前景颜色
+        :param activebackground: 为关闭按钮触发时的背景颜色
+        :param activeforeground: 为关闭按钮触发时的前景颜色
         """
         self.close_button = tk.Button(self, text=text, border=0, font=font,
                                       background=background, foreground=foreground,
@@ -735,8 +810,14 @@ class DevHeaderBar(tk.Frame):
                             background="#ffffff", foreground="#000000",
                             activebackground="#e9e9e9", activeforeground="#b5b5b5"):
         """
-        为标题栏添加最大化按钮，text为最大化按钮的文本，font为最大化按钮的字体，background为最大化按钮的背景颜色，
-        foreground为最大化按钮的前景颜色，activebackground为最大化按钮触发时的背景颜色，activeforeground为最大化按钮触发时的前景颜色
+        为标题栏添加最大化按钮，
+
+        :param text: 为最大化按钮的文本
+        :param font: 为最大化按钮的字体
+        :param background: 为最大化按钮的背景颜色
+        :param foreground: 为最大化按钮的前景颜色
+        :param activebackground: 为最大化按钮触发时的背景颜色
+        :param activeforeground: 为最大化按钮触发时的前景颜色
         """
         self.maxmize_button = tk.Button(self, text=text, border=0, font=font,
                                         background=background, foreground=foreground,
@@ -748,8 +829,14 @@ class DevHeaderBar(tk.Frame):
                             background="#ffffff", foreground="#000000",
                             activebackground="#e9e9e9", activeforeground="#b5b5b5"):
         """
-        为标题栏添加最小化按钮，text为最小化按钮的文本，font为最小化按钮的字体，background为最小化按钮的背景颜色，
-        foreground为最小化按钮的前景颜色，activebackground为最小化按钮触发时的背景颜色，activeforeground为最小化按钮触发时的前景颜色
+        为标题栏添加最小化按钮，
+
+        :param text: 为最小化按钮的文本
+        :param font: 为最小化按钮的字体
+        :param background: 为最小化按钮的背景颜色
+        :param foreground: 为最小化按钮的前景颜色
+        :param activebackground: 为最小化按钮触发时的背景颜色
+        :param activeforeground: 为最小化按钮触发时的前景颜色
         """
         self.minimize_button = tk.Button(self, text=text, border=0, font=font,
                                          background=background, foreground=foreground,
@@ -820,19 +907,27 @@ class DevObject(object):
 
     def add_widget(self, widget: tk.Widget, id: str):
         """
-        添加组件，widget为被存储的组件，id为存储组件的ID
+        添加组件
+
+        :param widget: 为被存储的组件
+        :param id: 为存储组件的ID
         """
         self.obj[id] = widget
 
     def set_widget(self, id: str, widget: tk.Widget):
         """
-        设置组件，id为存储组件的ID，widget为被存储的组件
+        设置组件
+
+        :param widget: 为被存储的组件
+        :param id: 为存储组件的ID
         """
         self.obj[id] = widget
 
     def get_widget(self, id: str) -> tk.Widget:
         """
-        获取组件，id为存储组件的ID
+        获取组件
+
+        :param id: 为存储组件的ID
         """
         return self.obj[id]
 
@@ -940,9 +1035,9 @@ class DevStatusBar(tk.Frame):
         """
         简单的状态栏，使用show可以将它显示出来，使用add_status在鼠标指针移动到组件上时，状态栏会显示状态文本。
 
-        :param master:
-        :param default_text:
-        :param background
+        :param master: 父组件
+        :param default_text: 默认文字
+        :param background: 背景颜色
         """
         super(DevStatusBar, self).__init__(master=master, background=background, )
         self.widgetlist = []
@@ -1040,7 +1135,9 @@ class DevWindow(tk.Tk):
     def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto,
                    mica: bool = False, acrylic: bool = False, hexColor: bool = False):
         """
-        设置窗口材质为亚克力，mode为主题默认是自动
+        设置窗口材质为亚克力，
+
+        :param mode: 为主题默认是自动
         """
         if mica:
             self.mica(mode)
@@ -1064,7 +1161,10 @@ class DevWindow(tk.Tk):
 
     def wm_mica(self, mode: Literal["auto", "light", "dark"] = Auto, all: bool = False):
         """
-        设置窗口材质为云母，mode为主题默认是自动，all选择是否隐藏整个窗口。
+        设置窗口材质为云母
+
+        :param mode: 为主题默认是自动
+        :param all: 选择是否隐藏整个窗口。
         """
         import platform
         if platform.system() == "Windows":
@@ -1115,7 +1215,9 @@ class DevWindow(tk.Tk):
 
     def wm_statusbar(self, statusBar: tk.Widget = None):
         """
-        设置状态栏，statusBar为被设置的状态栏
+        设置状态栏，
+
+        :param statusBar: 为被设置的状态栏
         """
         self._statusBar = statusBar
         self._statusBar.pack(fill=tk.X, side=tk.BOTTOM)
@@ -1125,7 +1227,9 @@ class DevWindow(tk.Tk):
 
     def wm_titlebar(self, titleBar: DevHeaderBar = None):
         """
-        设置标题栏，titleBar为被设置的标题栏
+        设置标题栏，
+
+        :param titleBar: 为被设置的标题栏
         """
         self.minsize(100, 30)
         self._titlebar = titleBar
@@ -1176,7 +1280,11 @@ class DevTooltip(DevToplevel):
         """
         用于给组件设定工具提示
 
-        widget表示设置工具提示的组件，window表示设置组件的窗口，message表示工具提示的文本，after表示几秒之后显示，border是否设定为窗口的边框。
+        :param widget: 表示设置工具提示的组件
+        :param window: 表示设置组件的窗口
+        :param message: 表示工具提示的文本
+        :param after: 表示几秒之后显示
+        :param border: 是否设定为窗口的边框
         """
         super(DevTooltip, self).__init__()
         self.configure(background=background, relief=tk.RAISED, border=1)
